# acfunSDK - websocket

<br />

<p align="center">
<a href="https://github.com/dolaCmeo/acfunSDK">
<img height="100" src="https://s3.dualstack.us-east-2.amazonaws.com/pythondotorg-assets/media/files/python-logo-only.svg" alt="">
<img height="100" src="https://ali-imgs.acfun.cn/kos/nlav10360/static/common/widget/header/img/acfunlogo.11a9841251f31e1a3316.svg" alt="">
</a>
</p>

<br />

acfunsdk是 **非官方的 [AcFun弹幕视频网][acfun.cn]** Python库。

> `acfunsdk-ws` 是`acfunsdk`的附属组件，提供websocket通信支持。

- - -


<details>
<summary>依赖库</summary>

**依赖: 包含在 `requirements.txt` 中**

+ [`acfunsdk`](https://pypi.org/project/acfunsdk/)`>=0.9.7`

WebSocket通信及数据处理:
+ [`websocket-client`](https://pypi.org/project/websocket-client/)`>=1.4`
+ [`pycryptodome`](https://pypi.org/project/pycryptodome/)`>=3.15`
+ [`protobuf`](https://pypi.org/project/protobuf/)`==3.20.1`
+ [`proto-plus`](https://pypi.org/project/proto-plus/)`==1.22.1`
+ [`filetype`](https://pypi.org/project/filetype/)`>=1.1`

>内置+修改: 
>
>+ [`blackboxprotobuf`](https://pypi.org/project/blackboxprotobuf/)

</details>

- - -

## About Me

[![ac彩娘-阿部高和](https://tx-free-imgs2.acfun.cn/kimg/bs2/zt-image-host/ChQwODliOGVhYzRjMTBmOGM0ZWY1ZRCIzNcv.gif)][dolacfun]
[♂ 整点大香蕉🍌][acfunsdk_page]
<img alt="AcFunCard" align="right" src="https://discovery.sunness.dev/39088">

- - - 

[dolacfun]: https://www.acfun.cn/u/39088
[acfunsdk_page]: https://www.acfun.cn/a/ac37416587

[acfun.cn]: https://www.acfun.cn/
[Issue]: https://github.com/dolaCmeo/acfunSDK/issues
[python]: https://www.python.org/downloads/
[venv]: https://docs.python.org/zh-cn/3.8/library/venv.html
